from ai.stigmer.agentic.agentinstance.v1 import api_pb2 as _api_pb2
from ai.stigmer.commons.rpc import pagination_pb2 as _pagination_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AgentInstanceId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class GetAgentInstancesByAgentRequest(_message.Message):
    __slots__ = ("agent_id", "page_info")
    AGENT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_INFO_FIELD_NUMBER: _ClassVar[int]
    agent_id: str
    page_info: _pagination_pb2.PageInfo
    def __init__(self, agent_id: _Optional[str] = ..., page_info: _Optional[_Union[_pagination_pb2.PageInfo, _Mapping]] = ...) -> None: ...

class AgentInstanceList(_message.Message):
    __slots__ = ("total_count", "items")
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total_count: int
    items: _containers.RepeatedCompositeFieldContainer[_api_pb2.AgentInstance]
    def __init__(self, total_count: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_api_pb2.AgentInstance, _Mapping]]] = ...) -> None: ...

class ListAgentInstancesRequest(_message.Message):
    __slots__ = ("org", "labels", "page_info")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ORG_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    PAGE_INFO_FIELD_NUMBER: _ClassVar[int]
    org: str
    labels: _containers.ScalarMap[str, str]
    page_info: _pagination_pb2.PageInfo
    def __init__(self, org: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ..., page_info: _Optional[_Union[_pagination_pb2.PageInfo, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/tenancy/project/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/tenancy/project/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ai/stigmer/tenancy/project/v1/spec.proto\x12\x1d\x61i.stigmer.tenancy.project.v1\x1a\'ai/stigmer/commons/apiresource/io.proto\"\xa0\x01\n\x0bProjectSpec\x12\x1f\n\x0b\x65ntry_point\x18\x01 \x01(\tR\nentryPoint\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12N\n\x07members\x18\x03 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceR\x07membersB\xc7\x01\n!com.ai.stigmer.tenancy.project.v1B\tSpecProtoP\x01\xa2\x02\x04\x41STP\xaa\x02\x1d\x41i.Stigmer.Tenancy.Project.V1\xca\x02\x1d\x41i\\Stigmer\\Tenancy\\Project\\V1\xe2\x02)Ai\\Stigmer\\Tenancy\\Project\\V1\\GPBMetadata\xea\x02!Ai::Stigmer::Tenancy::Project::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.tenancy.project.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ai.stigmer.tenancy.project.v1B\tSpecProtoP\001\242\002\004ASTP\252\002\035Ai.Stigmer.Tenancy.Project.V1\312\002\035Ai\\Stigmer\\Tenancy\\Project\\V1\342\002)Ai\\Stigmer\\Tenancy\\Project\\V1\\GPBMetadata\352\002!Ai::Stigmer::Tenancy::Project::V1'
  _globals['_PROJECTSPEC']._serialized_start=117
  _globals['_PROJECTSPEC']._serialized_end=277
# @@protoc_insertion_point(module_scope)



from ai.stigmer.iam.iampolicy.v1.rpcauthorization import io_pb2 as _io_pb2
from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
CONFIG_FIELD_NUMBER: _ClassVar[int]
config: _descriptor.FieldDescriptor
IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
is_public: _descriptor.FieldDescriptor
IS_SKIP_AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
is_skip_authorization: _descriptor.FieldDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/identityaccount/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/identityaccount/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2
from ai.stigmer.iam.identityaccount.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2
from ai.stigmer.iam.identityaccount.v1 import io_pb2 as ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_io__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ai/stigmer/iam/identityaccount/v1/query.proto\x12!ai.stigmer.iam.identityaccount.v1\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a+ai/stigmer/commons/apiresource/status.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto\x1a+ai/stigmer/iam/identityaccount/v1/api.proto\x1a*ai/stigmer/iam/identityaccount/v1/io.proto\x1a\x1bgoogle/protobuf/empty.proto2\xae\x06\n\x1eIdentityAccountQueryController\x12\xa6\x01\n\x03get\x12\x34.ai.stigmer.iam.identityaccount.v1.IdentityAccountId\x1a\x32.ai.stigmer.iam.identityaccount.v1.IdentityAccount\"5\xc2\xb8\x18\x31\x08\x03\x10\x0b\"\x05value*$unauthorized to get identity account\x12Z\n\x06whoAmI\x12\x16.google.protobuf.Empty\x1a\x32.ai.stigmer.iam.identityaccount.v1.IdentityAccount\"\x04\xd0\xb8\x18\x01\x12\xb0\x01\n\ngetByEmail\x12\x37.ai.stigmer.iam.identityaccount.v1.IdentityAccountEmail\x1a\x32.ai.stigmer.iam.identityaccount.v1.IdentityAccount\"5\xc2\xb8\x18\x31\x08\x03\x10\x0b\"\x05value*$unauthorized to get identity account\x12\xa1\x01\n\ngetByIdpId\x12(.ai.stigmer.iam.identityaccount.v1.IdpId\x1a\x32.ai.stigmer.iam.identityaccount.v1.IdentityAccount\"5\xc2\xb8\x18\x31\x08\x03\x10\x0b\"\x05value*$unauthorized to get identity account\x12\xa9\x01\n\x0cgetActorInfo\x12\x34.ai.stigmer.iam.identityaccount.v1.IdentityAccountId\x1a\x35.ai.stigmer.commons.apiresource.ApiResourceAuditActor\",\xc2\xb8\x18(\x08\x03\x10\x0b*\"unauthorized to look up actor info\x1a\x04\xa0\xff+\x0b\x42\xdc\x01\n%com.ai.stigmer.iam.identityaccount.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SII\xaa\x02!Ai.Stigmer.Iam.Identityaccount.V1\xca\x02!Ai\\Stigmer\\Iam\\Identityaccount\\V1\xe2\x02-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Iam::Identityaccount::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.identityaccount.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.iam.identityaccount.v1B\nQueryProtoP\001\242\002\004ASII\252\002!Ai.Stigmer.Iam.Identityaccount.V1\312\002!Ai\\Stigmer\\Iam\\Identityaccount\\V1\342\002-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\352\002%Ai::Stigmer::Iam::Identityaccount::V1'
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER']._loaded_options = None
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER']._serialized_options = b'\240\377+\013'
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\0301\010\003\020\013\"\005value*$unauthorized to get identity account'
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER'].methods_by_name['whoAmI']._loaded_options = None
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER'].methods_by_name['whoAmI']._serialized_options = b'\320\270\030\001'
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER'].methods_by_name['getByEmail']._loaded_options = None
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER'].methods_by_name['getByEmail']._serialized_options = b'\302\270\0301\010\003\020\013\"\005value*$unauthorized to get identity account'
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER'].methods_by_name['getByIdpId']._loaded_options = None
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER'].methods_by_name['getByIdpId']._serialized_options = b'\302\270\0301\010\003\020\013\"\005value*$unauthorized to get identity account'
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER'].methods_by_name['getActorInfo']._loaded_options = None
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER'].methods_by_name['getActorInfo']._serialized_options = b'\302\270\030(\010\003\020\013*\"unauthorized to look up actor info'
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER']._serialized_start=373
  _globals['_IDENTITYACCOUNTQUERYCONTROLLER']._serialized_end=1187
# @@protoc_insertion_point(module_scope)



from ai.stigmer.agentic.mcpserver.v1 import status_pb2 as _status_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class McpServerId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class UpdateDiscoveredCapabilitiesInput(_message.Message):
    __slots__ = ("mcp_server_id", "discovered_capabilities")
    MCP_SERVER_ID_FIELD_NUMBER: _ClassVar[int]
    DISCOVERED_CAPABILITIES_FIELD_NUMBER: _ClassVar[int]
    mcp_server_id: str
    discovered_capabilities: _status_pb2.DiscoveredCapabilities
    def __init__(self, mcp_server_id: _Optional[str] = ..., discovered_capabilities: _Optional[_Union[_status_pb2.DiscoveredCapabilities, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.iam.identityprovider.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2


class IdentityProviderCommandControllerStub(object):
    """IdentityProviderCommandController provides write operations for identity providers.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.apply = channel.unary_unary(
                '/ai.stigmer.iam.identityprovider.v1.IdentityProviderCommandController/apply',
                request_serializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.FromString,
                _registered_method=True)
        self.create = channel.unary_unary(
                '/ai.stigmer.iam.identityprovider.v1.IdentityProviderCommandController/create',
                request_serializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/ai.stigmer.iam.identityprovider.v1.IdentityProviderCommandController/update',
                request_serializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/ai.stigmer.iam.identityprovider.v1.IdentityProviderCommandController/delete',
                request_serializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceDeleteInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.FromString,
                _registered_method=True)


class IdentityProviderCommandControllerServicer(object):
    """IdentityProviderCommandController provides write operations for identity providers.
    """

    def apply(self, request, context):
        """Create or update an identity provider (Kubernetes-style apply).
        If the resource doesn't exist: creates a new identity provider.
        If the resource exists: updates the existing identity provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create(self, request, context):
        """Create a new identity provider.
        The creator's organization owns the identity provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Update an existing identity provider.
        Requires can_edit permission on the identity provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Delete an identity provider.
        Deletion is blocked if any platform-managed organizations reference this identity provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IdentityProviderCommandControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'apply': grpc.unary_unary_rpc_method_handler(
                    servicer.apply,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.SerializeToString,
            ),
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceDeleteInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.iam.identityprovider.v1.IdentityProviderCommandController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.iam.identityprovider.v1.IdentityProviderCommandController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class IdentityProviderCommandController(object):
    """IdentityProviderCommandController provides write operations for identity providers.
    """

    @staticmethod
    def apply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.identityprovider.v1.IdentityProviderCommandController/apply',
            ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.identityprovider.v1.IdentityProviderCommandController/create',
            ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.identityprovider.v1.IdentityProviderCommandController/update',
            ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.identityprovider.v1.IdentityProviderCommandController/delete',
            ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceDeleteInput.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_identityprovider_dot_v1_dot_api__pb2.IdentityProvider.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/session/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/session/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.session.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2
from ai.stigmer.agentic.session.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ai/stigmer/agentic/session/v1/query.proto\x12\x1d\x61i.stigmer.agentic.session.v1\x1a\'ai/stigmer/agentic/session/v1/api.proto\x1a&ai/stigmer/agentic/session/v1/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\x90\x03\n\x16SessionQueryController\x12\x85\x01\n\x03get\x12(.ai.stigmer.agentic.session.v1.SessionId\x1a&.ai.stigmer.agentic.session.v1.Session\",\xc2\xb8\x18(\x08\x03\x10*\"\x05value*\x1bunauthorized to get session\x12l\n\x04list\x12\x32.ai.stigmer.agentic.session.v1.ListSessionsRequest\x1a*.ai.stigmer.agentic.session.v1.SessionList\"\x04\xd0\xb8\x18\x01\x12z\n\x0blistByAgent\x12\x39.ai.stigmer.agentic.session.v1.ListSessionsByAgentRequest\x1a*.ai.stigmer.agentic.session.v1.SessionList\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+*B\xc8\x01\n!com.ai.stigmer.agentic.session.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1d\x41i.Stigmer.Agentic.Session.V1\xca\x02\x1d\x41i\\Stigmer\\Agentic\\Session\\V1\xe2\x02)Ai\\Stigmer\\Agentic\\Session\\V1\\GPBMetadata\xea\x02!Ai::Stigmer::Agentic::Session::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.session.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ai.stigmer.agentic.session.v1B\nQueryProtoP\001\242\002\004ASAS\252\002\035Ai.Stigmer.Agentic.Session.V1\312\002\035Ai\\Stigmer\\Agentic\\Session\\V1\342\002)Ai\\Stigmer\\Agentic\\Session\\V1\\GPBMetadata\352\002!Ai::Stigmer::Agentic::Session::V1'
  _globals['_SESSIONQUERYCONTROLLER']._loaded_options = None
  _globals['_SESSIONQUERYCONTROLLER']._serialized_options = b'\240\377+*'
  _globals['_SESSIONQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_SESSIONQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\030(\010\003\020*\"\005value*\033unauthorized to get session'
  _globals['_SESSIONQUERYCONTROLLER'].methods_by_name['list']._loaded_options = None
  _globals['_SESSIONQUERYCONTROLLER'].methods_by_name['list']._serialized_options = b'\320\270\030\001'
  _globals['_SESSIONQUERYCONTROLLER'].methods_by_name['listByAgent']._loaded_options = None
  _globals['_SESSIONQUERYCONTROLLER'].methods_by_name['listByAgent']._serialized_options = b'\320\270\030\001'
  _globals['_SESSIONQUERYCONTROLLER']._serialized_start=283
  _globals['_SESSIONQUERYCONTROLLER']._serialized_end=683
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agent/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agent/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.environment.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_spec__pb2
from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ai/stigmer/agentic/agent/v1/spec.proto\x12\x1b\x61i.stigmer.agentic.agent.v1\x1a,ai/stigmer/agentic/environment/v1/spec.proto\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x1b\x62uf/validate/validate.proto\"\xaa\x05\n\tAgentSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\x19\n\x08icon_url\x18\x02 \x01(\tR\x07iconUrl\x12+\n\x0cinstructions\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\nR\x0cinstructions\x12\xdf\x01\n\x11mcp_server_usages\x18\x04 \x03(\x0b\x32+.ai.stigmer.agentic.agent.v1.McpServerUsageB\x85\x01\xbaH\x81\x01\x92\x01~\"|\xba\x01y\n\x16mcp_server_usages.kind\x12?mcp_server_usages must reference resources with kind=mcp_server\x1a\x1ethis.mcp_server_ref.kind == 44R\x0fmcpServerUsages\x12\xbb\x01\n\nskill_refs\x18\x05 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceBf\xbaH_\x92\x01\\\"Z\xba\x01W\n\x0fskill_refs.kind\x12\x33skill_refs must reference resources with kind=skill\x1a\x0fthis.kind == 43\xe0\x85,+R\tskillRefs\x12\x44\n\nsub_agents\x18\x06 \x03(\x0b\x32%.ai.stigmer.agentic.agent.v1.SubAgentR\tsubAgents\x12M\n\x08\x65nv_spec\x18\x07 \x01(\x0b\x32\x32.ai.stigmer.agentic.environment.v1.EnvironmentSpecR\x07\x65nvSpec\"\xa1\x03\n\x08SubAgent\x12\x1a\n\x04name\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12+\n\x0cinstructions\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\nR\x0cinstructions\x12\x45\n\nmcp_access\x18\x04 \x03(\x0b\x32&.ai.stigmer.agentic.agent.v1.McpAccessR\tmcpAccess\x12\xbb\x01\n\nskill_refs\x18\x05 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceBf\xbaH_\x92\x01\\\"Z\xba\x01W\n\x0fskill_refs.kind\x12\x33skill_refs must reference resources with kind=skill\x1a\x0fthis.kind == 43\xe0\x85,+R\tskillRefs\x12%\n\x0emodel_override\x18\x06 \x01(\tR\rmodelOverride\"\x88\x02\n\x0eMcpServerUsage\x12\x66\n\x0emcp_server_ref\x18\x01 \x01(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceB\n\xbaH\x03\xc8\x01\x01\xe0\x85,,R\x0cmcpServerRef\x12#\n\renabled_tools\x18\x02 \x03(\tR\x0c\x65nabledTools\x12i\n\x17tool_approval_overrides\x18\x03 \x03(\x0b\x32\x31.ai.stigmer.agentic.agent.v1.ToolApprovalOverrideR\x15toolApprovalOverrides\"W\n\tMcpAccess\x12%\n\nmcp_server\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tmcpServer\x12#\n\renabled_tools\x18\x02 \x03(\tR\x0c\x65nabledTools\"\x83\x01\n\x14ToolApprovalOverride\x12$\n\ttool_name\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x08toolName\x12+\n\x11requires_approval\x18\x02 \x01(\x08R\x10requiresApproval\x12\x18\n\x07message\x18\x03 \x01(\tR\x07messageB\xbd\x01\n\x1f\x63om.ai.stigmer.agentic.agent.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02\x1b\x41i.Stigmer.Agentic.Agent.V1\xca\x02\x1b\x41i\\Stigmer\\Agentic\\Agent\\V1\xe2\x02\'Ai\\Stigmer\\Agentic\\Agent\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Agentic::Agent::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agent.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.agentic.agent.v1B\tSpecProtoP\001\242\002\004ASAA\252\002\033Ai.Stigmer.Agentic.Agent.V1\312\002\033Ai\\Stigmer\\Agentic\\Agent\\V1\342\002\'Ai\\Stigmer\\Agentic\\Agent\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Agentic::Agent::V1'
  _globals['_AGENTSPEC'].fields_by_name['instructions']._loaded_options = None
  _globals['_AGENTSPEC'].fields_by_name['instructions']._serialized_options = b'\272H\004r\002\020\n'
  _globals['_AGENTSPEC'].fields_by_name['mcp_server_usages']._loaded_options = None
  _globals['_AGENTSPEC'].fields_by_name['mcp_server_usages']._serialized_options = b'\272H\201\001\222\001~\"|\272\001y\n\026mcp_server_usages.kind\022?mcp_server_usages must reference resources with kind=mcp_server\032\036this.mcp_server_ref.kind == 44'
  _globals['_AGENTSPEC'].fields_by_name['skill_refs']._loaded_options = None
  _globals['_AGENTSPEC'].fields_by_name['skill_refs']._serialized_options = b'\272H_\222\001\\\"Z\272\001W\n\017skill_refs.kind\0223skill_refs must reference resources with kind=skill\032\017this.kind == 43\340\205,+'
  _globals['_SUBAGENT'].fields_by_name['name']._loaded_options = None
  _globals['_SUBAGENT'].fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SUBAGENT'].fields_by_name['instructions']._loaded_options = None
  _globals['_SUBAGENT'].fields_by_name['instructions']._serialized_options = b'\272H\004r\002\020\n'
  _globals['_SUBAGENT'].fields_by_name['skill_refs']._loaded_options = None
  _globals['_SUBAGENT'].fields_by_name['skill_refs']._serialized_options = b'\272H_\222\001\\\"Z\272\001W\n\017skill_refs.kind\0223skill_refs must reference resources with kind=skill\032\017this.kind == 43\340\205,+'
  _globals['_MCPSERVERUSAGE'].fields_by_name['mcp_server_ref']._loaded_options = None
  _globals['_MCPSERVERUSAGE'].fields_by_name['mcp_server_ref']._serialized_options = b'\272H\003\310\001\001\340\205,,'
  _globals['_MCPACCESS'].fields_by_name['mcp_server']._loaded_options = None
  _globals['_MCPACCESS'].fields_by_name['mcp_server']._serialized_options = b'\272H\003\310\001\001'
  _globals['_TOOLAPPROVALOVERRIDE'].fields_by_name['tool_name']._loaded_options = None
  _globals['_TOOLAPPROVALOVERRIDE'].fields_by_name['tool_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_AGENTSPEC']._serialized_start=240
  _globals['_AGENTSPEC']._serialized_end=922
  _globals['_SUBAGENT']._serialized_start=925
  _globals['_SUBAGENT']._serialized_end=1342
  _globals['_MCPSERVERUSAGE']._serialized_start=1345
  _globals['_MCPSERVERUSAGE']._serialized_end=1609
  _globals['_MCPACCESS']._serialized_start=1611
  _globals['_MCPACCESS']._serialized_end=1698
  _globals['_TOOLAPPROVALOVERRIDE']._serialized_start=1701
  _globals['_TOOLAPPROVALOVERRIDE']._serialized_end=1832
# @@protoc_insertion_point(module_scope)



import datetime

from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as _api_resource_kind_pb2
from ai.stigmer.commons.apiresource import enum_pb2 as _enum_pb2
from ai.stigmer.commons.rpc import pagination_pb2 as _pagination_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SearchRequest(_message.Message):
    __slots__ = ("kinds", "query", "org", "exclude_public", "page")
    KINDS_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    ORG_FIELD_NUMBER: _ClassVar[int]
    EXCLUDE_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    kinds: _containers.RepeatedScalarFieldContainer[_api_resource_kind_pb2.ApiResourceKind]
    query: str
    org: str
    exclude_public: bool
    page: _pagination_pb2.PageInfo
    def __init__(self, kinds: _Optional[_Iterable[_Union[_api_resource_kind_pb2.ApiResourceKind, str]]] = ..., query: _Optional[str] = ..., org: _Optional[str] = ..., exclude_public: bool = ..., page: _Optional[_Union[_pagination_pb2.PageInfo, _Mapping]] = ...) -> None: ...

class SearchResponse(_message.Message):
    __slots__ = ("entries", "counts_by_kind", "total_count", "total_pages")
    class CountsByKindEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    COUNTS_BY_KIND_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_PAGES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[SearchResult]
    counts_by_kind: _containers.ScalarMap[str, int]
    total_count: int
    total_pages: int
    def __init__(self, entries: _Optional[_Iterable[_Union[SearchResult, _Mapping]]] = ..., counts_by_kind: _Optional[_Mapping[str, int]] = ..., total_count: _Optional[int] = ..., total_pages: _Optional[int] = ...) -> None: ...

class SearchResult(_message.Message):
    __slots__ = ("kind", "id", "name", "slug", "qualified_slug", "org", "description", "visibility", "tags", "created_at", "updated_at", "score")
    KIND_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SLUG_FIELD_NUMBER: _ClassVar[int]
    QUALIFIED_SLUG_FIELD_NUMBER: _ClassVar[int]
    ORG_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    kind: _api_resource_kind_pb2.ApiResourceKind
    id: str
    name: str
    slug: str
    qualified_slug: str
    org: str
    description: str
    visibility: _enum_pb2.ApiResourceVisibility
    tags: _containers.RepeatedScalarFieldContainer[str]
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    score: float
    def __init__(self, kind: _Optional[_Union[_api_resource_kind_pb2.ApiResourceKind, str]] = ..., id: _Optional[str] = ..., name: _Optional[str] = ..., slug: _Optional[str] = ..., qualified_slug: _Optional[str] = ..., org: _Optional[str] = ..., description: _Optional[str] = ..., visibility: _Optional[_Union[_enum_pb2.ApiResourceVisibility, str]] = ..., tags: _Optional[_Iterable[str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., score: _Optional[float] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AuthorizationScopeType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    AUTHORIZATION_SCOPE_TYPE_UNSPECIFIED: _ClassVar[AuthorizationScopeType]
    AUTHORIZATION_SCOPE_TYPE_PLATFORM: _ClassVar[AuthorizationScopeType]
    AUTHORIZATION_SCOPE_TYPE_ORGANIZATION: _ClassVar[AuthorizationScopeType]
    AUTHORIZATION_SCOPE_TYPE_PARENT: _ClassVar[AuthorizationScopeType]
    AUTHORIZATION_SCOPE_TYPE_OWNER_ONLY: _ClassVar[AuthorizationScopeType]
    AUTHORIZATION_SCOPE_TYPE_NONE: _ClassVar[AuthorizationScopeType]

class OwnerAttributionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    OWNER_ATTRIBUTION_TYPE_UNSPECIFIED: _ClassVar[OwnerAttributionType]
    OWNER_ATTRIBUTION_TYPE_DIRECT: _ClassVar[OwnerAttributionType]
    OWNER_ATTRIBUTION_TYPE_INHERITED: _ClassVar[OwnerAttributionType]
    OWNER_ATTRIBUTION_TYPE_SELF: _ClassVar[OwnerAttributionType]
    OWNER_ATTRIBUTION_TYPE_NONE: _ClassVar[OwnerAttributionType]
AUTHORIZATION_SCOPE_TYPE_UNSPECIFIED: AuthorizationScopeType
AUTHORIZATION_SCOPE_TYPE_PLATFORM: AuthorizationScopeType
AUTHORIZATION_SCOPE_TYPE_ORGANIZATION: AuthorizationScopeType
AUTHORIZATION_SCOPE_TYPE_PARENT: AuthorizationScopeType
AUTHORIZATION_SCOPE_TYPE_OWNER_ONLY: AuthorizationScopeType
AUTHORIZATION_SCOPE_TYPE_NONE: AuthorizationScopeType
OWNER_ATTRIBUTION_TYPE_UNSPECIFIED: OwnerAttributionType
OWNER_ATTRIBUTION_TYPE_DIRECT: OwnerAttributionType
OWNER_ATTRIBUTION_TYPE_INHERITED: OwnerAttributionType
OWNER_ATTRIBUTION_TYPE_SELF: OwnerAttributionType
OWNER_ATTRIBUTION_TYPE_NONE: OwnerAttributionType

class VisibilityConfig(_message.Message):
    __slots__ = ("supports_public",)
    SUPPORTS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    supports_public: bool
    def __init__(self, supports_public: bool = ...) -> None: ...

class ParentRelationConfig(_message.Message):
    __slots__ = ("kind", "relation", "spec_field")
    KIND_FIELD_NUMBER: _ClassVar[int]
    RELATION_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_FIELD_NUMBER: _ClassVar[int]
    kind: str
    relation: str
    spec_field: str
    def __init__(self, kind: _Optional[str] = ..., relation: _Optional[str] = ..., spec_field: _Optional[str] = ...) -> None: ...

class AuthorizationConfig(_message.Message):
    __slots__ = ("scope_type", "owner_type", "parent", "additional_parents", "visibility", "requires_creator_tuple")
    SCOPE_TYPE_FIELD_NUMBER: _ClassVar[int]
    OWNER_TYPE_FIELD_NUMBER: _ClassVar[int]
    PARENT_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_PARENTS_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    REQUIRES_CREATOR_TUPLE_FIELD_NUMBER: _ClassVar[int]
    scope_type: AuthorizationScopeType
    owner_type: OwnerAttributionType
    parent: ParentRelationConfig
    additional_parents: _containers.RepeatedCompositeFieldContainer[ParentRelationConfig]
    visibility: VisibilityConfig
    requires_creator_tuple: bool
    def __init__(self, scope_type: _Optional[_Union[AuthorizationScopeType, str]] = ..., owner_type: _Optional[_Union[OwnerAttributionType, str]] = ..., parent: _Optional[_Union[ParentRelationConfig, _Mapping]] = ..., additional_parents: _Optional[_Iterable[_Union[ParentRelationConfig, _Mapping]]] = ..., visibility: _Optional[_Union[VisibilityConfig, _Mapping]] = ..., requires_creator_tuple: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowinstance/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowinstance/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ai/stigmer/agentic/workflowinstance/v1/spec.proto\x12&ai.stigmer.agentic.workflowinstance.v1\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x1b\x62uf/validate/validate.proto\"\xba\x02\n\x14WorkflowInstanceSpec\x12(\n\x0bworkflow_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\nworkflowId\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\xd5\x01\n\x10\x65nvironment_refs\x18\x03 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceBt\xbaHq\x92\x01n\"l\xba\x01i\n\x15\x65nvironment_refs.kind\x12?environment_refs must reference resources with kind=environment\x1a\x0fthis.kind == 52R\x0f\x65nvironmentRefsB\xf4\x01\n*com.ai.stigmer.agentic.workflowinstance.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02&Ai.Stigmer.Agentic.Workflowinstance.V1\xca\x02&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\xe2\x02\x32\x41i\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\xea\x02*Ai::Stigmer::Agentic::Workflowinstance::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowinstance.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.ai.stigmer.agentic.workflowinstance.v1B\tSpecProtoP\001\242\002\004ASAW\252\002&Ai.Stigmer.Agentic.Workflowinstance.V1\312\002&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\342\0022Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\352\002*Ai::Stigmer::Agentic::Workflowinstance::V1'
  _globals['_WORKFLOWINSTANCESPEC'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_WORKFLOWINSTANCESPEC'].fields_by_name['workflow_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_WORKFLOWINSTANCESPEC'].fields_by_name['environment_refs']._loaded_options = None
  _globals['_WORKFLOWINSTANCESPEC'].fields_by_name['environment_refs']._serialized_options = b'\272Hq\222\001n\"l\272\001i\n\025environment_refs.kind\022?environment_refs must reference resources with kind=environment\032\017this.kind == 52'
  _globals['_WORKFLOWINSTANCESPEC']._serialized_start=164
  _globals['_WORKFLOWINSTANCESPEC']._serialized_end=478
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ExecutionPhase(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EXECUTION_PHASE_UNSPECIFIED: _ClassVar[ExecutionPhase]
    EXECUTION_PENDING: _ClassVar[ExecutionPhase]
    EXECUTION_IN_PROGRESS: _ClassVar[ExecutionPhase]
    EXECUTION_COMPLETED: _ClassVar[ExecutionPhase]
    EXECUTION_FAILED: _ClassVar[ExecutionPhase]
    EXECUTION_CANCELLED: _ClassVar[ExecutionPhase]
    EXECUTION_TERMINATED: _ClassVar[ExecutionPhase]
    EXECUTION_PAUSED: _ClassVar[ExecutionPhase]

class WorkflowTaskType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    WORKFLOW_TASK_TYPE_UNSPECIFIED: _ClassVar[WorkflowTaskType]
    WORKFLOW_TASK_AGENT_INVOCATION: _ClassVar[WorkflowTaskType]
    WORKFLOW_TASK_APPROVAL: _ClassVar[WorkflowTaskType]
    WORKFLOW_TASK_API_CALL: _ClassVar[WorkflowTaskType]
    WORKFLOW_TASK_CONDITIONAL: _ClassVar[WorkflowTaskType]
    WORKFLOW_TASK_PARALLEL: _ClassVar[WorkflowTaskType]
    WORKFLOW_TASK_TRANSFORM: _ClassVar[WorkflowTaskType]
    WORKFLOW_TASK_CUSTOM: _ClassVar[WorkflowTaskType]

class WorkflowTaskStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    WORKFLOW_TASK_STATUS_UNSPECIFIED: _ClassVar[WorkflowTaskStatus]
    WORKFLOW_TASK_PENDING: _ClassVar[WorkflowTaskStatus]
    WORKFLOW_TASK_IN_PROGRESS: _ClassVar[WorkflowTaskStatus]
    WORKFLOW_TASK_COMPLETED: _ClassVar[WorkflowTaskStatus]
    WORKFLOW_TASK_FAILED: _ClassVar[WorkflowTaskStatus]
    WORKFLOW_TASK_SKIPPED: _ClassVar[WorkflowTaskStatus]
    WORKFLOW_TASK_WAITING_APPROVAL: _ClassVar[WorkflowTaskStatus]
EXECUTION_PHASE_UNSPECIFIED: ExecutionPhase
EXECUTION_PENDING: ExecutionPhase
EXECUTION_IN_PROGRESS: ExecutionPhase
EXECUTION_COMPLETED: ExecutionPhase
EXECUTION_FAILED: ExecutionPhase
EXECUTION_CANCELLED: ExecutionPhase
EXECUTION_TERMINATED: ExecutionPhase
EXECUTION_PAUSED: ExecutionPhase
WORKFLOW_TASK_TYPE_UNSPECIFIED: WorkflowTaskType
WORKFLOW_TASK_AGENT_INVOCATION: WorkflowTaskType
WORKFLOW_TASK_APPROVAL: WorkflowTaskType
WORKFLOW_TASK_API_CALL: WorkflowTaskType
WORKFLOW_TASK_CONDITIONAL: WorkflowTaskType
WORKFLOW_TASK_PARALLEL: WorkflowTaskType
WORKFLOW_TASK_TRANSFORM: WorkflowTaskType
WORKFLOW_TASK_CUSTOM: WorkflowTaskType
WORKFLOW_TASK_STATUS_UNSPECIFIED: WorkflowTaskStatus
WORKFLOW_TASK_PENDING: WorkflowTaskStatus
WORKFLOW_TASK_IN_PROGRESS: WorkflowTaskStatus
WORKFLOW_TASK_COMPLETED: WorkflowTaskStatus
WORKFLOW_TASK_FAILED: WorkflowTaskStatus
WORKFLOW_TASK_SKIPPED: WorkflowTaskStatus
WORKFLOW_TASK_WAITING_APPROVAL: WorkflowTaskStatus



from ai.stigmer.agentic.workflowinstance.v1 import api_pb2 as _api_pb2
from ai.stigmer.commons.rpc import pagination_pb2 as _pagination_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WorkflowInstanceId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class GetWorkflowInstancesByWorkflowRequest(_message.Message):
    __slots__ = ("workflow_id", "page_info")
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_INFO_FIELD_NUMBER: _ClassVar[int]
    workflow_id: str
    page_info: _pagination_pb2.PageInfo
    def __init__(self, workflow_id: _Optional[str] = ..., page_info: _Optional[_Union[_pagination_pb2.PageInfo, _Mapping]] = ...) -> None: ...

class WorkflowInstanceList(_message.Message):
    __slots__ = ("total_pages", "entries")
    TOTAL_PAGES_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    total_pages: int
    entries: _containers.RepeatedCompositeFieldContainer[_api_pb2.WorkflowInstance]
    def __init__(self, total_pages: _Optional[int] = ..., entries: _Optional[_Iterable[_Union[_api_pb2.WorkflowInstance, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/tasks/wait.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/tasks/wait.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ai/stigmer/agentic/workflow/v1/tasks/wait.proto\x12$ai.stigmer.agentic.workflow.v1.tasks\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb9\x02\n\x08\x44uration\x12\x12\n\x04\x64\x61ys\x18\x01 \x01(\rR\x04\x64\x61ys\x12\x14\n\x05hours\x18\x02 \x01(\rR\x05hours\x12\x18\n\x07minutes\x18\x03 \x01(\rR\x07minutes\x12\x18\n\x07seconds\x18\x04 \x01(\rR\x07seconds\x12\"\n\x0cmilliseconds\x18\x05 \x01(\rR\x0cmilliseconds:\xaa\x01\xbaH\xa6\x01\x1a\xa3\x01\n\x11\x64uration.non_zero\x12,at least one duration field must be non-zero\x1a`this.days > 0 || this.hours > 0 || this.minutes > 0 || this.seconds > 0 || this.milliseconds > 0\"\xa9\x01\n\x0eWaitTaskConfig\x12L\n\x08\x64uration\x18\x01 \x01(\x0b\x32..ai.stigmer.agentic.workflow.v1.tasks.DurationH\x00R\x08\x64uration\x12\x32\n\x05until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x05until:\x08\xea\x8b,\x04waitB\x0b\n\twait_typeB\xed\x01\n(com.ai.stigmer.agentic.workflow.v1.tasksB\tWaitProtoP\x01\xa2\x02\x06\x41SAWVT\xaa\x02$Ai.Stigmer.Agentic.Workflow.V1.Tasks\xca\x02$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\xea\x02)Ai::Stigmer::Agentic::Workflow::V1::Tasksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.tasks.wait_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.workflow.v1.tasksB\tWaitProtoP\001\242\002\006ASAWVT\252\002$Ai.Stigmer.Agentic.Workflow.V1.Tasks\312\002$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\342\0020Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\352\002)Ai::Stigmer::Agentic::Workflow::V1::Tasks'
  _globals['_DURATION']._loaded_options = None
  _globals['_DURATION']._serialized_options = b'\272H\246\001\032\243\001\n\021duration.non_zero\022,at least one duration field must be non-zero\032`this.days > 0 || this.hours > 0 || this.minutes > 0 || this.seconds > 0 || this.milliseconds > 0'
  _globals['_WAITTASKCONFIG']._loaded_options = None
  _globals['_WAITTASKCONFIG']._serialized_options = b'\352\213,\004wait'
  _globals['_DURATION']._serialized_start=204
  _globals['_DURATION']._serialized_end=517
  _globals['_WAITTASKCONFIG']._serialized_start=520
  _globals['_WAITTASKCONFIG']._serialized_end=689
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class WorkflowTaskKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    workflow_task_kind_unspecified: _ClassVar[WorkflowTaskKind]
    set_vars: _ClassVar[WorkflowTaskKind]
    http_call: _ClassVar[WorkflowTaskKind]
    grpc_call: _ClassVar[WorkflowTaskKind]
    activity_call: _ClassVar[WorkflowTaskKind]
    switch_case: _ClassVar[WorkflowTaskKind]
    for_each: _ClassVar[WorkflowTaskKind]
    fork: _ClassVar[WorkflowTaskKind]
    try_catch: _ClassVar[WorkflowTaskKind]
    listen: _ClassVar[WorkflowTaskKind]
    wait: _ClassVar[WorkflowTaskKind]
    raise_error: _ClassVar[WorkflowTaskKind]
    run_workflow: _ClassVar[WorkflowTaskKind]
    agent_call: _ClassVar[WorkflowTaskKind]
workflow_task_kind_unspecified: WorkflowTaskKind
set_vars: WorkflowTaskKind
http_call: WorkflowTaskKind
grpc_call: WorkflowTaskKind
activity_call: WorkflowTaskKind
switch_case: WorkflowTaskKind
for_each: WorkflowTaskKind
fork: WorkflowTaskKind
try_catch: WorkflowTaskKind
listen: WorkflowTaskKind
wait: WorkflowTaskKind
raise_error: WorkflowTaskKind
run_workflow: WorkflowTaskKind
agent_call: WorkflowTaskKind



from ai.stigmer.iam.iampolicy.v1 import api_pb2 as _api_pb2
from ai.stigmer.iam.iampolicy.v1 import spec_pb2 as _spec_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApiResourceRefView(_message.Message):
    __slots__ = ("kind", "id", "relation", "name", "email", "slug", "avatar", "members", "teams")
    KIND_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    RELATION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    SLUG_FIELD_NUMBER: _ClassVar[int]
    AVATAR_FIELD_NUMBER: _ClassVar[int]
    MEMBERS_FIELD_NUMBER: _ClassVar[int]
    TEAMS_FIELD_NUMBER: _ClassVar[int]
    kind: str
    id: str
    relation: str
    name: str
    email: str
    slug: str
    avatar: str
    members: _containers.RepeatedCompositeFieldContainer[ApiResourceRefView]
    teams: _containers.RepeatedCompositeFieldContainer[ApiResourceRefView]
    def __init__(self, kind: _Optional[str] = ..., id: _Optional[str] = ..., relation: _Optional[str] = ..., name: _Optional[str] = ..., email: _Optional[str] = ..., slug: _Optional[str] = ..., avatar: _Optional[str] = ..., members: _Optional[_Iterable[_Union[ApiResourceRefView, _Mapping]]] = ..., teams: _Optional[_Iterable[_Union[ApiResourceRefView, _Mapping]]] = ...) -> None: ...

class IamPolicyId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class PrincipalResourceInput(_message.Message):
    __slots__ = ("principal", "resource")
    PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    principal: _spec_pb2.ApiResourceRef
    resource: _spec_pb2.ApiResourceRef
    def __init__(self, principal: _Optional[_Union[_spec_pb2.ApiResourceRef, _Mapping]] = ..., resource: _Optional[_Union[_spec_pb2.ApiResourceRef, _Mapping]] = ...) -> None: ...

class ResourcePrincipalsInput(_message.Message):
    __slots__ = ("resource", "principals")
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    PRINCIPALS_FIELD_NUMBER: _ClassVar[int]
    resource: _spec_pb2.ApiResourceRef
    principals: _containers.RepeatedCompositeFieldContainer[_spec_pb2.ApiResourceRef]
    def __init__(self, resource: _Optional[_Union[_spec_pb2.ApiResourceRef, _Mapping]] = ..., principals: _Optional[_Iterable[_Union[_spec_pb2.ApiResourceRef, _Mapping]]] = ...) -> None: ...

class RevokeOrgAccessInput(_message.Message):
    __slots__ = ("identity_account_id", "organization_id")
    IDENTITY_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    identity_account_id: str
    organization_id: str
    def __init__(self, identity_account_id: _Optional[str] = ..., organization_id: _Optional[str] = ...) -> None: ...

class IamPoliciesList(_message.Message):
    __slots__ = ("entries",)
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[_api_pb2.IamPolicy]
    def __init__(self, entries: _Optional[_Iterable[_Union[_api_pb2.IamPolicy, _Mapping]]] = ...) -> None: ...

class ListResourceAccessInput(_message.Message):
    __slots__ = ("resource", "include_inherited")
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_INHERITED_FIELD_NUMBER: _ClassVar[int]
    resource: _spec_pb2.ApiResourceRef
    include_inherited: bool
    def __init__(self, resource: _Optional[_Union[_spec_pb2.ApiResourceRef, _Mapping]] = ..., include_inherited: bool = ...) -> None: ...

class ResourceAccessByPrincipalList(_message.Message):
    __slots__ = ("entries",)
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[PrincipalAccess]
    def __init__(self, entries: _Optional[_Iterable[_Union[PrincipalAccess, _Mapping]]] = ...) -> None: ...

class PrincipalAccess(_message.Message):
    __slots__ = ("principal", "roles")
    PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    ROLES_FIELD_NUMBER: _ClassVar[int]
    principal: ApiResourceRefView
    roles: _containers.RepeatedCompositeFieldContainer[RoleGrant]
    def __init__(self, principal: _Optional[_Union[ApiResourceRefView, _Mapping]] = ..., roles: _Optional[_Iterable[_Union[RoleGrant, _Mapping]]] = ...) -> None: ...

class RoleGrant(_message.Message):
    __slots__ = ("role", "owner_resource", "is_inherited")
    ROLE_FIELD_NUMBER: _ClassVar[int]
    OWNER_RESOURCE_FIELD_NUMBER: _ClassVar[int]
    IS_INHERITED_FIELD_NUMBER: _ClassVar[int]
    role: RoleInfo
    owner_resource: _spec_pb2.ApiResourceRef
    is_inherited: bool
    def __init__(self, role: _Optional[_Union[RoleInfo, _Mapping]] = ..., owner_resource: _Optional[_Union[_spec_pb2.ApiResourceRef, _Mapping]] = ..., is_inherited: bool = ...) -> None: ...

class ResourceAccessByRoleList(_message.Message):
    __slots__ = ("entries",)
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[RoleAccess]
    def __init__(self, entries: _Optional[_Iterable[_Union[RoleAccess, _Mapping]]] = ...) -> None: ...

class RoleAccess(_message.Message):
    __slots__ = ("role", "principals")
    ROLE_FIELD_NUMBER: _ClassVar[int]
    PRINCIPALS_FIELD_NUMBER: _ClassVar[int]
    role: RoleGrant
    principals: _containers.RepeatedCompositeFieldContainer[ApiResourceRefView]
    def __init__(self, role: _Optional[_Union[RoleGrant, _Mapping]] = ..., principals: _Optional[_Iterable[_Union[ApiResourceRefView, _Mapping]]] = ...) -> None: ...

class RoleInfo(_message.Message):
    __slots__ = ("id", "code", "name", "description")
    ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    code: str
    name: str
    description: str
    def __init__(self, id: _Optional[str] = ..., code: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class PrincipalResourceRoles(_message.Message):
    __slots__ = ("roles",)
    ROLES_FIELD_NUMBER: _ClassVar[int]
    roles: _containers.RepeatedCompositeFieldContainer[RoleInfo]
    def __init__(self, roles: _Optional[_Iterable[_Union[RoleInfo, _Mapping]]] = ...) -> None: ...

class CheckAuthorizationInput(_message.Message):
    __slots__ = ("policy", "contextual_policies")
    POLICY_FIELD_NUMBER: _ClassVar[int]
    CONTEXTUAL_POLICIES_FIELD_NUMBER: _ClassVar[int]
    policy: _spec_pb2.IamPolicySpec
    contextual_policies: _containers.RepeatedCompositeFieldContainer[_spec_pb2.IamPolicySpec]
    def __init__(self, policy: _Optional[_Union[_spec_pb2.IamPolicySpec, _Mapping]] = ..., contextual_policies: _Optional[_Iterable[_Union[_spec_pb2.IamPolicySpec, _Mapping]]] = ...) -> None: ...

class CheckAuthorizationResult(_message.Message):
    __slots__ = ("is_authorized",)
    IS_AUTHORIZED_FIELD_NUMBER: _ClassVar[int]
    is_authorized: bool
    def __init__(self, is_authorized: bool = ...) -> None: ...

class ListAuthorizedResourceIdsInput(_message.Message):
    __slots__ = ("principal", "resource_kind", "relation", "contextual_policies")
    PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_KIND_FIELD_NUMBER: _ClassVar[int]
    RELATION_FIELD_NUMBER: _ClassVar[int]
    CONTEXTUAL_POLICIES_FIELD_NUMBER: _ClassVar[int]
    principal: _spec_pb2.ApiResourceRef
    resource_kind: str
    relation: str
    contextual_policies: _containers.RepeatedCompositeFieldContainer[_spec_pb2.IamPolicySpec]
    def __init__(self, principal: _Optional[_Union[_spec_pb2.ApiResourceRef, _Mapping]] = ..., resource_kind: _Optional[str] = ..., relation: _Optional[str] = ..., contextual_policies: _Optional[_Iterable[_Union[_spec_pb2.IamPolicySpec, _Mapping]]] = ...) -> None: ...

class AuthorizedResourceIdsList(_message.Message):
    __slots__ = ("resource_ids",)
    RESOURCE_IDS_FIELD_NUMBER: _ClassVar[int]
    resource_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, resource_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ListAuthorizedPrincipalIdsInput(_message.Message):
    __slots__ = ("resource", "principal_kind", "relation", "contextual_policies")
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    PRINCIPAL_KIND_FIELD_NUMBER: _ClassVar[int]
    RELATION_FIELD_NUMBER: _ClassVar[int]
    CONTEXTUAL_POLICIES_FIELD_NUMBER: _ClassVar[int]
    resource: _spec_pb2.ApiResourceRef
    principal_kind: str
    relation: str
    contextual_policies: _containers.RepeatedCompositeFieldContainer[_spec_pb2.IamPolicySpec]
    def __init__(self, resource: _Optional[_Union[_spec_pb2.ApiResourceRef, _Mapping]] = ..., principal_kind: _Optional[str] = ..., relation: _Optional[str] = ..., contextual_policies: _Optional[_Iterable[_Union[_spec_pb2.IamPolicySpec, _Mapping]]] = ...) -> None: ...

class AuthorizedPrincipalIdsList(_message.Message):
    __slots__ = ("principal_ids",)
    PRINCIPAL_IDS_FIELD_NUMBER: _ClassVar[int]
    principal_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, principal_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class GetPrincipalsCountInput(_message.Message):
    __slots__ = ("org_id", "principal_kind")
    ORG_ID_FIELD_NUMBER: _ClassVar[int]
    PRINCIPAL_KIND_FIELD_NUMBER: _ClassVar[int]
    org_id: str
    principal_kind: str
    def __init__(self, org_id: _Optional[str] = ..., principal_kind: _Optional[str] = ...) -> None: ...

class PrincipalsCount(_message.Message):
    __slots__ = ("count",)
    COUNT_FIELD_NUMBER: _ClassVar[int]
    count: int
    def __init__(self, count: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_enum__pb2
from ai.stigmer.agentic.agentexecution.v1 import usage_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_usage__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ai/stigmer/agentic/agentexecution/v1/io.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a.ai/stigmer/agentic/agentexecution/v1/api.proto\x1a/ai/stigmer/agentic/agentexecution/v1/enum.proto\x1a\x30\x61i/stigmer/agentic/agentexecution/v1/usage.proto\x1a\x1b\x62uf/validate/validate.proto\"0\n\x10\x41gentExecutionId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\")\n\tSessionId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\x85\x01\n\x12\x41gentExecutionList\x12\x1f\n\x0btotal_pages\x18\x01 \x01(\x05R\ntotalPages\x12N\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecutionR\x07\x65ntries\"\xb8\x01\n\x1aListAgentExecutionsRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12J\n\x05phase\x18\x03 \x01(\x0e\x32\x34.ai.stigmer.agentic.agentexecution.v1.ExecutionPhaseR\x05phase\x12\x12\n\x04tags\x18\x04 \x03(\tR\x04tags\"\x88\x01\n#ListAgentExecutionsBySessionRequest\x12%\n\nsession_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tsessionId\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xa9\x01\n\x1f\x41gentExecutionUpdateStatusInput\x12*\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12Z\n\x06status\x18\x02 \x01(\x0b\x32:.ai.stigmer.agentic.agentexecution.v1.AgentExecutionStatusB\x06\xbaH\x03\xc8\x01\x01R\x06status\"\xeb\x01\n\x13SubmitApprovalInput\x12\x35\n\x12\x61gent_execution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x10\x61gentExecutionId\x12)\n\x0ctool_call_id\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\ntoolCallId\x12X\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x34.ai.stigmer.agentic.agentexecution.v1.ApprovalActionB\n\xbaH\x07\x82\x01\x04\x10\x01 \x00R\x06\x61\x63tion\x12\x18\n\x07\x63omment\x18\x04 \x01(\tR\x07\x63omment\"o\n\x14\x41pprovalDecisionList\x12W\n\tdecisions\x18\x01 \x03(\x0b\x32\x39.ai.stigmer.agentic.agentexecution.v1.SubmitApprovalInputR\tdecisions\"L\n\x19\x43\x61ncelAgentExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"O\n\x1cTerminateAgentExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"5\n\x1aRecoverAgentExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\"K\n\x18PauseAgentExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"4\n\x19ResumeAgentExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\"\x83\x01\n\x17UploadAttachmentRequest\x12#\n\x08\x66ilename\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x08\x66ilename\x12 \n\x07\x63ontent\x18\x02 \x01(\x0c\x42\x06\xbaH\x03\xc8\x01\x01R\x07\x63ontent\x12!\n\x0c\x63ontent_type\x18\x03 \x01(\tR\x0b\x63ontentType\";\n\x18UploadAttachmentResponse\x12\x1f\n\x0bstorage_key\x18\x01 \x01(\tR\nstorageKey\"u\n\x1dGetArtifactDownloadUrlRequest\x12*\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12(\n\x0bstorage_key\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\nstorageKey\"b\n\x1eGetArtifactDownloadUrlResponse\x12!\n\x0c\x64ownload_url\x18\x01 \x01(\tR\x0b\x64ownloadUrl\x12\x1d\n\nexpires_at\x18\x02 \x01(\tR\texpiresAt\"\xad\x01\n\x19GetArtifactContentRequest\x12*\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12(\n\x0bstorage_key\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\nstorageKey\x12\x1b\n\tmax_bytes\x18\x03 \x01(\x03R\x08maxBytes\x12\x1d\n\nentry_path\x18\x04 \x01(\tR\tentryPath\"\xa1\x01\n\x1aGetArtifactContentResponse\x12\x18\n\x07\x63ontent\x18\x01 \x01(\x0cR\x07\x63ontent\x12!\n\x0c\x63ontent_type\x18\x02 \x01(\tR\x0b\x63ontentType\x12(\n\x10total_size_bytes\x18\x03 \x01(\x03R\x0etotalSizeBytes\x12\x1c\n\ttruncated\x18\x04 \x01(\x08R\ttruncated\"D\n\x1aGetSessionUsageReportInput\x12&\n\nsession_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\tsessionId\"\x8d\x04\n\x1bGetSessionUsageReportOutput\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\'\n\x0f\x65xecution_count\x18\x02 \x01(\x05R\x0e\x65xecutionCount\x12S\n\x0btotal_usage\x18\x03 \x01(\x0b\x32\x32.ai.stigmer.agentic.agentexecution.v1.UsageMetricsR\ntotalUsage\x12[\n\nexecutions\x18\x04 \x03(\x0b\x32;.ai.stigmer.agentic.agentexecution.v1.ExecutionUsageSummaryR\nexecutions\x12Y\n\x0fmodel_breakdown\x18\x05 \x03(\x0b\x32\x30.ai.stigmer.agentic.agentexecution.v1.ModelUsageR\x0emodelBreakdown\x12?\n\x1ctotal_summarization_cost_usd\x18\x06 \x01(\x01R\x19totalSummarizationCostUsd\x12,\n\x12\x66irst_execution_at\x18\x07 \x01(\tR\x10\x66irstExecutionAt\x12*\n\x11last_execution_at\x18\x08 \x01(\tR\x0flastExecutionAt\"\xb0\x01\n\x18GetAgentUsageReportInput\x12\"\n\x08\x61gent_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x07\x61gentId\x12\x1b\n\tfrom_date\x18\x02 \x01(\tR\x08\x66romDate\x12\x17\n\x07to_date\x18\x03 \x01(\tR\x06toDate\x12\x1b\n\tpage_size\x18\x04 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x05 \x01(\tR\tpageToken\"\xfc\x03\n\x19GetAgentUsageReportOutput\x12\x19\n\x08\x61gent_id\x18\x01 \x01(\tR\x07\x61gentId\x12\x1d\n\nagent_name\x18\x02 \x01(\tR\tagentName\x12S\n\x0btotal_usage\x18\x03 \x01(\x0b\x32\x32.ai.stigmer.agentic.agentexecution.v1.UsageMetricsR\ntotalUsage\x12Y\n\x0fmodel_breakdown\x18\x04 \x03(\x0b\x32\x30.ai.stigmer.agentic.agentexecution.v1.ModelUsageR\x0emodelBreakdown\x12U\n\x08sessions\x18\x05 \x03(\x0b\x32\x39.ai.stigmer.agentic.agentexecution.v1.SessionUsageSummaryR\x08sessions\x12%\n\x0etotal_sessions\x18\x06 \x01(\x05R\rtotalSessions\x12)\n\x10total_executions\x18\x07 \x01(\x05R\x0ftotalExecutions\x12$\n\x0etotal_cost_usd\x18\x08 \x01(\x01R\x0ctotalCostUsd\x12&\n\x0fnext_page_token\x18\t \x01(\tR\rnextPageToken\"\x80\x01\n\x16GetOrgUsageReportInput\x12\x1e\n\x06org_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x05orgId\x12$\n\tfrom_date\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x08\x66romDate\x12 \n\x07to_date\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x06toDate\"\xe3\x03\n\x17GetOrgUsageReportOutput\x12\x15\n\x06org_id\x18\x01 \x01(\tR\x05orgId\x12!\n\x0ctotal_agents\x18\x02 \x01(\x05R\x0btotalAgents\x12%\n\x0etotal_sessions\x18\x03 \x01(\x05R\rtotalSessions\x12)\n\x10total_executions\x18\x04 \x01(\x05R\x0ftotalExecutions\x12$\n\x0etotal_cost_usd\x18\x05 \x01(\x01R\x0ctotalCostUsd\x12Y\n\x0fmodel_breakdown\x18\x06 \x03(\x0b\x32\x30.ai.stigmer.agentic.agentexecution.v1.ModelUsageR\x0emodelBreakdown\x12\x64\n\x12top_agents_by_cost\x18\x07 \x03(\x0b\x32\x37.ai.stigmer.agentic.agentexecution.v1.AgentUsageSummaryR\x0ftopAgentsByCost\x12U\n\x0b\x64\x61ily_costs\x18\x08 \x03(\x0b\x32\x34.ai.stigmer.agentic.agentexecution.v1.DailyCostEntryR\ndailyCosts\"\xc1\x03\n\x15\x45xecutionUsageSummary\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x1d\n\nstarted_at\x18\x02 \x01(\tR\tstartedAt\x12!\n\x0c\x63ompleted_at\x18\x03 \x01(\tR\x0b\x63ompletedAt\x12#\n\rprompt_tokens\x18\x04 \x01(\x05R\x0cpromptTokens\x12+\n\x11\x63ompletion_tokens\x18\x05 \x01(\x05R\x10\x63ompletionTokens\x12*\n\x11\x63\x61\x63he_read_tokens\x18\x06 \x01(\x05R\x0f\x63\x61\x63heReadTokens\x12,\n\x12\x65stimated_cost_usd\x18\x07 \x01(\x01R\x10\x65stimatedCostUsd\x12#\n\rprimary_model\x18\x08 \x01(\tR\x0cprimaryModel\x12&\n\x0fsub_agent_count\x18\t \x01(\x05R\rsubAgentCount\x12J\n\x05phase\x18\n \x01(\x0e\x32\x34.ai.stigmer.agentic.agentexecution.v1.ExecutionPhaseR\x05phase\"\x88\x02\n\x13SessionUsageSummary\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\'\n\x0f\x65xecution_count\x18\x02 \x01(\x05R\x0e\x65xecutionCount\x12!\n\x0ctotal_tokens\x18\x03 \x01(\x05R\x0btotalTokens\x12,\n\x12\x65stimated_cost_usd\x18\x04 \x01(\x01R\x10\x65stimatedCostUsd\x12,\n\x12\x66irst_execution_at\x18\x05 \x01(\tR\x10\x66irstExecutionAt\x12*\n\x11last_execution_at\x18\x06 \x01(\tR\x0flastExecutionAt\"\xc7\x01\n\x11\x41gentUsageSummary\x12\x19\n\x08\x61gent_id\x18\x01 \x01(\tR\x07\x61gentId\x12\x1d\n\nagent_name\x18\x02 \x01(\tR\tagentName\x12\'\n\x0f\x65xecution_count\x18\x03 \x01(\x05R\x0e\x65xecutionCount\x12!\n\x0ctotal_tokens\x18\x04 \x01(\x05R\x0btotalTokens\x12,\n\x12\x65stimated_cost_usd\x18\x05 \x01(\x01R\x10\x65stimatedCostUsd\"\x9e\x01\n\x0e\x44\x61ilyCostEntry\x12\x12\n\x04\x64\x61te\x18\x01 \x01(\tR\x04\x64\x61te\x12\'\n\x0f\x65xecution_count\x18\x02 \x01(\x05R\x0e\x65xecutionCount\x12!\n\x0ctotal_tokens\x18\x03 \x01(\x05R\x0btotalTokens\x12,\n\x12\x65stimated_cost_usd\x18\x04 \x01(\x01R\x10\x65stimatedCostUsdB\xe8\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\007IoProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_AGENTEXECUTIONID'].fields_by_name['value']._loaded_options = None
  _globals['_AGENTEXECUTIONID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SESSIONID'].fields_by_name['value']._loaded_options = None
  _globals['_SESSIONID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LISTAGENTEXECUTIONSBYSESSIONREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_LISTAGENTEXECUTIONSBYSESSIONREQUEST'].fields_by_name['session_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_AGENTEXECUTIONUPDATESTATUSINPUT'].fields_by_name['execution_id']._loaded_options = None
  _globals['_AGENTEXECUTIONUPDATESTATUSINPUT'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_AGENTEXECUTIONUPDATESTATUSINPUT'].fields_by_name['status']._loaded_options = None
  _globals['_AGENTEXECUTIONUPDATESTATUSINPUT'].fields_by_name['status']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SUBMITAPPROVALINPUT'].fields_by_name['agent_execution_id']._loaded_options = None
  _globals['_SUBMITAPPROVALINPUT'].fields_by_name['agent_execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SUBMITAPPROVALINPUT'].fields_by_name['tool_call_id']._loaded_options = None
  _globals['_SUBMITAPPROVALINPUT'].fields_by_name['tool_call_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SUBMITAPPROVALINPUT'].fields_by_name['action']._loaded_options = None
  _globals['_SUBMITAPPROVALINPUT'].fields_by_name['action']._serialized_options = b'\272H\007\202\001\004\020\001 \000'
  _globals['_CANCELAGENTEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_CANCELAGENTEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_TERMINATEAGENTEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_TERMINATEAGENTEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RECOVERAGENTEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_RECOVERAGENTEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_PAUSEAGENTEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_PAUSEAGENTEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RESUMEAGENTEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_RESUMEAGENTEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_UPLOADATTACHMENTREQUEST'].fields_by_name['filename']._loaded_options = None
  _globals['_UPLOADATTACHMENTREQUEST'].fields_by_name['filename']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_UPLOADATTACHMENTREQUEST'].fields_by_name['content']._loaded_options = None
  _globals['_UPLOADATTACHMENTREQUEST'].fields_by_name['content']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETARTIFACTDOWNLOADURLREQUEST'].fields_by_name['execution_id']._loaded_options = None
  _globals['_GETARTIFACTDOWNLOADURLREQUEST'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETARTIFACTDOWNLOADURLREQUEST'].fields_by_name['storage_key']._loaded_options = None
  _globals['_GETARTIFACTDOWNLOADURLREQUEST'].fields_by_name['storage_key']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETARTIFACTCONTENTREQUEST'].fields_by_name['execution_id']._loaded_options = None
  _globals['_GETARTIFACTCONTENTREQUEST'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETARTIFACTCONTENTREQUEST'].fields_by_name['storage_key']._loaded_options = None
  _globals['_GETARTIFACTCONTENTREQUEST'].fields_by_name['storage_key']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETSESSIONUSAGEREPORTINPUT'].fields_by_name['session_id']._loaded_options = None
  _globals['_GETSESSIONUSAGEREPORTINPUT'].fields_by_name['session_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETAGENTUSAGEREPORTINPUT'].fields_by_name['agent_id']._loaded_options = None
  _globals['_GETAGENTUSAGEREPORTINPUT'].fields_by_name['agent_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETORGUSAGEREPORTINPUT'].fields_by_name['org_id']._loaded_options = None
  _globals['_GETORGUSAGEREPORTINPUT'].fields_by_name['org_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETORGUSAGEREPORTINPUT'].fields_by_name['from_date']._loaded_options = None
  _globals['_GETORGUSAGEREPORTINPUT'].fields_by_name['from_date']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETORGUSAGEREPORTINPUT'].fields_by_name['to_date']._loaded_options = None
  _globals['_GETORGUSAGEREPORTINPUT'].fields_by_name['to_date']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_AGENTEXECUTIONID']._serialized_start=263
  _globals['_AGENTEXECUTIONID']._serialized_end=311
  _globals['_SESSIONID']._serialized_start=313
  _globals['_SESSIONID']._serialized_end=354
  _globals['_AGENTEXECUTIONLIST']._serialized_start=357
  _globals['_AGENTEXECUTIONLIST']._serialized_end=490
  _globals['_LISTAGENTEXECUTIONSREQUEST']._serialized_start=493
  _globals['_LISTAGENTEXECUTIONSREQUEST']._serialized_end=677
  _globals['_LISTAGENTEXECUTIONSBYSESSIONREQUEST']._serialized_start=680
  _globals['_LISTAGENTEXECUTIONSBYSESSIONREQUEST']._serialized_end=816
  _globals['_AGENTEXECUTIONUPDATESTATUSINPUT']._serialized_start=819
  _globals['_AGENTEXECUTIONUPDATESTATUSINPUT']._serialized_end=988
  _globals['_SUBMITAPPROVALINPUT']._serialized_start=991
  _globals['_SUBMITAPPROVALINPUT']._serialized_end=1226
  _globals['_APPROVALDECISIONLIST']._serialized_start=1228
  _globals['_APPROVALDECISIONLIST']._serialized_end=1339
  _globals['_CANCELAGENTEXECUTIONINPUT']._serialized_start=1341
  _globals['_CANCELAGENTEXECUTIONINPUT']._serialized_end=1417
  _globals['_TERMINATEAGENTEXECUTIONINPUT']._serialized_start=1419
  _globals['_TERMINATEAGENTEXECUTIONINPUT']._serialized_end=1498
  _globals['_RECOVERAGENTEXECUTIONINPUT']._serialized_start=1500
  _globals['_RECOVERAGENTEXECUTIONINPUT']._serialized_end=1553
  _globals['_PAUSEAGENTEXECUTIONINPUT']._serialized_start=1555
  _globals['_PAUSEAGENTEXECUTIONINPUT']._serialized_end=1630
  _globals['_RESUMEAGENTEXECUTIONINPUT']._serialized_start=1632
  _globals['_RESUMEAGENTEXECUTIONINPUT']._serialized_end=1684
  _globals['_UPLOADATTACHMENTREQUEST']._serialized_start=1687
  _globals['_UPLOADATTACHMENTREQUEST']._serialized_end=1818
  _globals['_UPLOADATTACHMENTRESPONSE']._serialized_start=1820
  _globals['_UPLOADATTACHMENTRESPONSE']._serialized_end=1879
  _globals['_GETARTIFACTDOWNLOADURLREQUEST']._serialized_start=1881
  _globals['_GETARTIFACTDOWNLOADURLREQUEST']._serialized_end=1998
  _globals['_GETARTIFACTDOWNLOADURLRESPONSE']._serialized_start=2000
  _globals['_GETARTIFACTDOWNLOADURLRESPONSE']._serialized_end=2098
  _globals['_GETARTIFACTCONTENTREQUEST']._serialized_start=2101
  _globals['_GETARTIFACTCONTENTREQUEST']._serialized_end=2274
  _globals['_GETARTIFACTCONTENTRESPONSE']._serialized_start=2277
  _globals['_GETARTIFACTCONTENTRESPONSE']._serialized_end=2438
  _globals['_GETSESSIONUSAGEREPORTINPUT']._serialized_start=2440
  _globals['_GETSESSIONUSAGEREPORTINPUT']._serialized_end=2508
  _globals['_GETSESSIONUSAGEREPORTOUTPUT']._serialized_start=2511
  _globals['_GETSESSIONUSAGEREPORTOUTPUT']._serialized_end=3036
  _globals['_GETAGENTUSAGEREPORTINPUT']._serialized_start=3039
  _globals['_GETAGENTUSAGEREPORTINPUT']._serialized_end=3215
  _globals['_GETAGENTUSAGEREPORTOUTPUT']._serialized_start=3218
  _globals['_GETAGENTUSAGEREPORTOUTPUT']._serialized_end=3726
  _globals['_GETORGUSAGEREPORTINPUT']._serialized_start=3729
  _globals['_GETORGUSAGEREPORTINPUT']._serialized_end=3857
  _globals['_GETORGUSAGEREPORTOUTPUT']._serialized_start=3860
  _globals['_GETORGUSAGEREPORTOUTPUT']._serialized_end=4343
  _globals['_EXECUTIONUSAGESUMMARY']._serialized_start=4346
  _globals['_EXECUTIONUSAGESUMMARY']._serialized_end=4795
  _globals['_SESSIONUSAGESUMMARY']._serialized_start=4798
  _globals['_SESSIONUSAGESUMMARY']._serialized_end=5062
  _globals['_AGENTUSAGESUMMARY']._serialized_start=5065
  _globals['_AGENTUSAGESUMMARY']._serialized_end=5264
  _globals['_DAILYCOSTENTRY']._serialized_start=5267
  _globals['_DAILYCOSTENTRY']._serialized_end=5425
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/apikey/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/apikey/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ai/stigmer/iam/apikey/v1/spec.proto\x12\x18\x61i.stigmer.iam.apikey.v1\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x01\n\nApiKeySpec\x12\x1f\n\x08key_hash\x18\x01 \x01(\tB\x04\xc8\x85,\x01R\x07keyHash\x12&\n\x0b\x66ingerprint\x18\x02 \x01(\tB\x04\xc8\x85,\x01R\x0b\x66ingerprint\x12\x39\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12#\n\rnever_expires\x18\x04 \x01(\x08R\x0cneverExpiresB\xae\x01\n\x1c\x63om.ai.stigmer.iam.apikey.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SIA\xaa\x02\x18\x41i.Stigmer.Iam.Apikey.V1\xca\x02\x18\x41i\\Stigmer\\Iam\\Apikey\\V1\xe2\x02$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\xea\x02\x1c\x41i::Stigmer::Iam::Apikey::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.apikey.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.ai.stigmer.iam.apikey.v1B\tSpecProtoP\001\242\002\004ASIA\252\002\030Ai.Stigmer.Iam.Apikey.V1\312\002\030Ai\\Stigmer\\Iam\\Apikey\\V1\342\002$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\352\002\034Ai::Stigmer::Iam::Apikey::V1'
  _globals['_APIKEYSPEC'].fields_by_name['key_hash']._loaded_options = None
  _globals['_APIKEYSPEC'].fields_by_name['key_hash']._serialized_options = b'\310\205,\001'
  _globals['_APIKEYSPEC'].fields_by_name['fingerprint']._loaded_options = None
  _globals['_APIKEYSPEC'].fields_by_name['fingerprint']._serialized_options = b'\310\205,\001'
  _globals['_APIKEYSPEC']._serialized_start=151
  _globals['_APIKEYSPEC']._serialized_end=332
# @@protoc_insertion_point(module_scope)
